"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const react_1 = tslib_1.__importStar(require("react"));
const auth0_spa_js_1 = tslib_1.__importDefault(require("@auth0/auth0-spa-js"));
const get_state_1 = tslib_1.__importDefault(require("./get-state"));
const context_1 = tslib_1.__importDefault(require("./context"));
const redirectAfterLogin = (appState, onRedirectCallback) => {
    if (!window) {
        return;
    }
    // We want to remove the state and the code from the querystring.
    window.history.replaceState({}, document && document.title, window && window.location.pathname);
    // Allow the implementation of custom redirect logic.
    if (onRedirectCallback) {
        onRedirectCallback(appState);
    }
};
const initAuth0 = (state, options, onRedirectCallback, onError) => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
    try {
        const client = yield auth0_spa_js_1.default(options);
        state.setClient(client);
        // If the user was redirect from Auth0, we need to handle the exchange or throw an error.
        if (window.location.search.includes('state=') || (window.location.search.includes('error=') || window.location.search.includes('code='))) {
            const { appState } = yield client.handleRedirectCallback();
            redirectAfterLogin(appState, onRedirectCallback);
        }
        const isAuthenticated = yield client.isAuthenticated();
        state.setAuthenticated(isAuthenticated);
        if (isAuthenticated) {
            const user = yield client.getUser();
            state.setUser(user);
        }
        state.setLoading(false);
    }
    catch (err) {
        state.setUser(null);
        state.setLoading(false);
        state.setAuthenticated(false);
        // Call a custom error handler if available.
        if (onError) {
            onError(err);
        }
        else {
            console.error(err);
        }
    }
});
function Auth0Provider(_a) {
    var { children, clientId, redirectUri, onRedirecting, onRedirectCallback, onError } = _a, props = tslib_1.__rest(_a, ["children", "clientId", "redirectUri", "onRedirecting", "onRedirectCallback", "onError"]);
    const state = get_state_1.default();
    const options = Object.assign({ client_id: clientId, redirect_uri: redirectUri }, props);
    react_1.useEffect(() => {
        initAuth0(state, options, onRedirectCallback, onError);
    }, []);
    // These values will be available in the context.
    const contextValues = {
        user: state.user,
        isAuthenticated: state.isAuthenticated,
        isLoading: state.isLoading,
        login: (...p) => state.client.loginWithRedirect(...p),
        logout: (...p) => state.client.logout(...p),
        getAccessToken: (...p) => state.client.getTokenSilently(...p),
        onRedirecting
    };
    return (react_1.default.createElement(context_1.default.Provider, { value: contextValues }, children));
}
exports.default = Auth0Provider;
//# sourceMappingURL=provider.js.map