"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const query_string_1 = require("query-string");
const react_1 = tslib_1.__importStar(require("react"));
const use_auth0_1 = tslib_1.__importDefault(require("./use-auth0"));
function getDisplayName(ChildComponent) {
    return ChildComponent.displayName || ChildComponent.name || 'Component';
}
function getReturnTo() {
    if (window && window.location) {
        return {
            pathname: window.location.pathname,
            query: query_string_1.parse(window.location.search)
        };
    }
    return null;
}
function getInitialPropsMethod(ChildComponent) {
    const ChildComponentNext = ChildComponent;
    return ChildComponentNext && ChildComponentNext.getInitialProps;
}
function WithLoginRequired(ChildComponent) {
    const WrappedComponent = (_a) => {
        var { path } = _a, rest = tslib_1.__rest(_a, ["path"]);
        const { isLoading, isAuthenticated, login, onRedirecting } = use_auth0_1.default();
        react_1.useEffect(() => {
            if (isLoading || isAuthenticated) {
                return;
            }
            login({
                appState: {
                    returnTo: getReturnTo()
                }
            });
        }, [isLoading, isAuthenticated, login, path]);
        return isAuthenticated === true ? (react_1.default.createElement(ChildComponent, Object.assign({}, rest))) : ((onRedirecting && onRedirecting()) || null);
    };
    // Add a displayname to the component.
    WrappedComponent.displayName = `WithLoginRequired(${getDisplayName(react_1.Component)})`;
    // Helper for Next.js support (getInitialProps)
    const getInitialProps = getInitialPropsMethod(ChildComponent);
    if (getInitialProps) {
        const WrappedComponentNext = WrappedComponent;
        WrappedComponentNext.getInitialProps = (args) => tslib_1.__awaiter(this, void 0, void 0, function* () { return getInitialProps(args); });
    }
    return WrappedComponent;
}
exports.default = WithLoginRequired;
//# sourceMappingURL=require-login.js.map